.. image:: https://img.shields.io/pypi/v/dwave-ocean-sdk.svg
    :target: https://pypi.python.org/pypi/dwave-ocean-sdk

.. image:: https://ci.appveyor.com/api/projects/status/c8ofdgyiy4w38lu3?svg=true
    :target: https://ci.appveyor.com/project/dwave-adtt/dwave-ocean-sdk

.. image:: https://circleci.com/gh/dwavesystems/dwave-ocean-sdk.svg?style=svg
    :target: https://circleci.com/gh/dwavesystems/dwave-ocean-sdk

.. index-start-marker

dwave-ocean-sdk
===============

Installer for D-Wave's Ocean Tools.


Installation
------------

.. installation-start-marker

Compatible with Python 2 and 3:

.. code-block:: bash

    pip install dwave-ocean-sdk

To install from source:

.. code-block:: bash

    python setup.py install

.. installation-end-marker

Next Steps
----------

For information on configuring solvers and using the Ocean tools, see
the `Ocean Documentation <https://docs.ocean.dwavesys.com/en/latest/>`_\ .
